Target Distributions
====================

.. inheritance-diagram:: gmmvi.experiments.target_distributions.lnpdf.LNPDF gmmvi.experiments.target_distributions.gmm.GMM_LNPDF gmmvi.experiments.target_distributions.student_t_mixture.StudentTMixture_LNPDF gmmvi.experiments.target_distributions.logistic_regression.LogisticRegression gmmvi.experiments.target_distributions.logistic_regression.LogisticRegression_minibatch gmmvi.experiments.target_distributions.planar_robot.PlanarRobot gmmvi.experiments.target_distributions.bnn.BNN_LNPDF gmmvi.experiments.target_distributions.talos_ik.Talos
    :parts: -4

.. autoclass:: gmmvi.experiments.target_distributions.lnpdf.LNPDF
   :members:
   :undoc-members:

.. autoclass:: gmmvi.experiments.target_distributions.gmm.GMM_LNPDF
   :members:
   :undoc-members:

.. autoclass:: gmmvi.experiments.target_distributions.student_t_mixture.StudentTMixture_LNPDF
   :members:
   :undoc-members:

.. autoclass:: gmmvi.experiments.target_distributions.logistic_regression.LogisticRegression
   :members:
   :undoc-members:

.. autoclass:: gmmvi.experiments.target_distributions.logistic_regression.LogisticRegression_minibatch
   :members:
   :undoc-members:

.. autoclass:: gmmvi.experiments.target_distributions.planar_robot.PlanarRobot
   :members:
   :undoc-members:

.. autoclass:: gmmvi.experiments.target_distributions.bnn.BNN_LNPDF
   :members:
   :undoc-members:

.. autoclass:: gmmvi.experiments.target_distributions.talos_ik.Talos
   :members:
   :undoc-members:
